GOOF----LE-8-2.0!8      ]  4 h      ] g  guile	 	g  define-module*	 	 	g  system	g  base	g  compile		 	
g  filenameS	f  system/base/compile.scm	g  importsS	
g  syntax	
 	 	g  language	 	 	g  message	 	 	g  vm	 	 	g  ice-9	g  regex	 	 	g  optargs	 	 	 g  receive	!  	"! 	#" 	$g  exportsS	%g  compiled-file-name	&g  compile-file	'g  compile-and-load	(g  read-and-compile	)g  	decompile	*%&'() 	+g  set-current-module	,+ 	-+ 	.g  error	/f  "thunk may only be entered once: ~a	0g  	call-once	1g  
string-append	2f  .XXXXXX	3g  mkstemp!	4f  wb	5g  with-throw-handler	6g  catch	76 	86 	9g  
stat:perms	:g  stat	;g  lognot	<g  umask	=g  chmod	>g  
close-port	?g  rename-file	@g  delete-file	Ag  call-with-output-file/atomic	Bg  	language?	Cg  lookup-language	Dg  ensure-language	Eg  system-error	Fg  mkdir	Gg  EEXIST	Hg  ENOENT	Ig  ensure-directory	Jg  dirname	Kg  throw	Lg  %compile-fallback-path	Mg  canonicalize-path	Ng  string-prefix?	Of  /	Pg  
string-length	Qg  
string-ref	Rg  	substring	Sg  %load-compiled-extensions	Tg  string-null?	Ug  warn	Vf  !invalid %load-compiled-extensions	Wf  .go	Xg  output-fileS	YX	Zg  fromS	[Z		\g  toS	]\		^g  envS	_^		`g  optsS	a`		bg  canonicalizationS	cb		dY[]_ac 	eg  current-language	fg  objcode	gg  default-environment	hg  relative	ig   %file-port-name-canonicalization	jf  ,failed to create path for auto-compiled file	kg  open-input-file	lg  
file-encoding	mg  set-port-encoding!	nf  UTF-8	og  language-printer	pZ	q\		r^		s`		tb		upqrst 	vg  value	wg  current-module	xg  map	yg  cdr	zg  lookup-compilation-order	{f  no way to compile	|f  to	}g  compile-passes	~g  compile-fold	g  language-joiner g  reverse g  find-language-joint f  BMultiple expressions read and compiled, but language has no joiner g  default-language-joiner g  language-reader g  eof-object? g  language-parser g  read-and-parse pqrs  g  
parameter?     g  	scm-error g  wrong-type-arg f  parameterize f  Not a parameter: ~S g  memq g  warningsS g  for-each g  lookup-warning-type g  warning g  unsupported-warning g  lookup-decompilation-order f  no way to decompile g  decompile-passes g  decompile-fold ^ []s  g  assemblyC 5    hh+     ]4	
#$*5 4- >  "  G   ./   h(   r   ] M$  4L >  "  G  "   NC   j       g  filenamef  system/base/compile.scm
	+			,	
			-		
	-			-		#	.	
 		%
   C    h   J   ] C    B       g  filenamef  system/base/compile.scm
	0	 		
   C./      h(   r   ] M$  4L >  "  G  "   NC   j       g  filenamef  system/base/compile.scm
	+			,	
			-		
	-			-		#	.	
 		%
   C   hX      ]	H O 4 O >   "  G  V4 >   X4>   "  G  CX4>   "  G  F           g  thunk
		T g  entered		T  g  filenamef  system/base/compile.scm
	(
		)			*	 		T  g  nameg  	call-once C0R12340589:     h   Z   ] 4L 56   R       g  filenamef  system/base/compile.scm
	=			=	<	
	=	0 		
   C    h   _   -  1  3 C     W       g  args
			  g  filenamef  system/base/compile.scm
	=	 			


   C;<=>? 	   hx      ]4LL>  "  G  4LO 5  $   "  
445 5  4L >  "  G   4L>  "  G  LL 6          g  t
	#	> g  perms
	>	[  g  filenamef  system/base/compile.scm
	9				:			=		#	=		2	>		5	>	$	;	>		>	=		A	?	
	K	?		P	?	
	\	@		u	A	 		u
   C>@    h(   o   -  1  3 4L>  "  G  L 6       g       g  args
			!  g  filenamef  system/base/compile.scm
	B			
	C		!	D	 			!


   C      h    R   ] L LLLLO LLO 6 J       g  filenamef  system/base/compile.scm
	7			8	 		
   C   h@   "  - . , 3 #  4 545 O 6        g  filename
		> g  proc		> g  	reference			> g  template			> g  tmp		)	>  g  filenamef  system/base/compile.scm
	3
		4			4	+		4			4		!	5		'	5	!	)	5		)	4		>	6	 		>	  g  nameg  call-with-output-file/atomic CARBC   h      ]4 5$   C 6         g  x
		  g  filenamef  system/base/compile.scm
	F
		G		
	G			I	 		  g  nameg  ensure-language CDR6EF     h   R   ] L 6J       g  filenamef  system/base/compile.scm
	Q			R	 		
   CGHIJK        hX     ]
$  "  $  C$  44L 5>  "  G  L 6 6            g  k
		R g  subr		R g  fmt			R g  args			R g  rest			R g  errno			R  g  filenamef  system/base/compile.scm
	S			T				T			T	%		T			V	
		U		#	Z	
	'	U		(	[	
	+	[		6	[	
	D	\	
	R	^	
 		R	   C h      ] O  O 6         g  dir
		  g  filenamef  system/base/compile.scm
	O
		P				P	 		  g  nameg  ensure-directory CIRL1MNOPQRSTUVW8IJ        h   ]   ] 4L 56   U       g  filenamef  system/base/compile.scm
 		 	4	
 	" 		
   C h   `   -  1  3 C     X       g  args
			  g  filenamef  system/base/compile.scm
 	 			


   C     h     ]	$  44 545$  "  B45	$  245:$  44
54	55"  "  	$  "  4
	5$  4	>  "  G  
"  	54O 5$  CCC      g  file
	  g  canon		n g  t	q  g  f    g  filenamef  system/base/compile.scm
	l
		~						 	$	 			q			q			q		#	p		*	r		3	r		7	p		8	s		B	s		F	r		G	u		K	u		L	u		U	u	/	_	u		q	x		q	x			y	 	y	 	y	 	x	 	z	 	z	 	z	 	|	 	}	 		 		  	  		 $	   g  nameg  compiled-file-name C%Rdefghi%.jklmnIJAoD(^Z\`    h0      ]44L554L LLLL5	 6              g  port
		)  g  filenamef  system/base/compile.scm
 		 		 		 		 		) 	
 		)   C  h     - /   0   3 
#  #  45 #  #  	45#  #  Y$  "  !4 5$  "  	4	 54
 545	4	$  	"  
>  "  G  445>  "  G  4O  >  "  G  ZCZF    ~      g  file
	  g  output-file	  g  from		  g  to		  g  env		  g  opts		  g  canonicalization		  g  t		n  g  comp	   g  in	   g  enc		    g  filenamef  system/base/compile.scm
 
	# 		1 		: 		I 		S 	)	a 		h 	!	n 		} 	  	  	  	  	  	  	  	  	  	  	%  	  	  	  	  	 	 
g  output-fileSg  fromS	g  toS	g  envS	g  optsS	g  canonicalizationS	   g  nameg  compile-file C&Ruevwhi(kZ\`^ 
  hx   n  - /   0   3 #  45 #  #  45 #  #  Y44 5	
>	  ZCZF     f      g  file
		s g  from		s g  to			s g  env			s g  opts			s g  canonicalization			s  g  filenamef  system/base/compile.scm
 
	 	,	( 	D	1 	 	> 	8	H 	-	Q 		T 		o 	 
		s
g  fromSg  toS	g  envS	g  optsS	g  canonicalizationS	   g  nameg  compile-and-load C'Rxyz.{|       h0      ]4 5$  "  
4 56        g  from
		/ g  to		/ g  opts			/ g  t			-  g  filenamef  system/base/compile.scm
 
	 		 		 		" 		& 	+	* 		/ 	 			/	  g  nameg  compile-passes C}R  hP   8  ] (  D4 L >  G  $  "   "   0      g  passes
		M g  x		M g  e			M g  cenv			M g  first?			M g  x		 	M g  e		 	M g  new-cenv		 	M  g  filenamef  system/base/compile.scm
 		 		 		 	 	 	!	 	 	# 		, 		6 		M 	
 		M	  g  nameg  lp C     h       ]O Q  6        g  passes
		 g  exp		 g  env			 g  opts			 g  lp			  g  filenamef  system/base/compile.scm
 
	 	 			  g  nameg  compile-fold C~Rz.{|        hh   W  ]"  &(  C45$  C"44 5$  "  
4 55"      O      g  from
		b g  to		b g  in			, g  lang			, g  t		8	V  g  filenamef  system/base/compile.scm
 
	 		 		 		 		  		# 		, 		, 		- 		0 		8 		G 		K 	#	O 	<	S 		X 		b 	 		b	  g  nameg  find-language-joint CR.     h(      ]"  L 6 $   (   C""ޯ       g  exps
		( g  env		(  g  filenamef  system/base/compile.scm
 		
 			 		 		 	
	 		 	!	 		 	 
		(	   C      h      ] O C      y       g  lang
		
  g  filenamef  system/base/compile.scm
 
 		
  g  nameg  default-language-joiner CR  h8   
  ]44 5545$  C4 5$  6C      g  lang
		8 g  port		8 g  cenv			8 g  exp			8 g  t		'	8  g  filenamef  system/base/compile.scm
 
	 	
	 		 	
	 		 		 		! 		' 		5 	0 		8	  g  nameg  read-and-parse CRefgDe>Z\^g`~}       h     ]#445 L545$  b4L>  "  G  44L5$  "  4L54 55	L
L$  "  4L5
L6	4445 LL5L>  G   "J      g  exps
	  g  env	  g  cenv		  g  x		  g  t		9	Q g  jexp	   g  jenv	   g  jcenv	    g  filenamef  system/base/compile.scm
 		 		 	#	 		 	
	 		 		 		2 		3 		9 		H 		R 		\ 		l 		s 	%	 	  	  	   	0  	   	  	  	  	 	 	  g  nameg  lp C 
    h     - /   0   3 
#  45 #  #  	45#  45454545$  "  4	
 >  "  G  4	5YO 		 Q 	4	>  ZCZF       g  port
	  g  from	  g  to		  g  env		  g  opts		  g  from		P  g  to		P  g  joint		]  g  t-30456		a  g  lp		    
g  filenamef  system/base/compile.scm
 
	 	!	( 		1 	 	@ 	!	C 		J 		P 		U 		] 		a 	  	  	  	 	 
g  fromSg  toS	g  envS	g  optsS	   g  nameg  read-and-compile C(Revg      h       ]	4 5$  C 6          g  w
		 g  t			  g  filenamef  system/base/compile.scm
 		 			 		 	#	 	 		   C~}    h     - /   0   3 #  45 #  #  	45#  45$  !4>  "  G  "   4	4
5 >  G C        g  x
	  g  from	  g  to		  g  env		  g  opts		  g  warnings		K	x g  warnings		X	q g  exp	   g  env	   g  cenv	    
g  filenamef  system/base/compile.scm
 
	 		( 		1 		@ 		C 		K 		P 		T 		W 		X 		[ 	
	y 		| 	  	  	 	 
g  fromSg  toS	g  envS	g  optsS	   g  nameg  compile CRxy.|    h0      ]4 5$  "  
4 56        g  from
		/ g  to		/ g  opts			/ g  t			-  g  filenamef  system/base/compile.scm

							"		&	-	*		/	 			/	  g  nameg  decompile-passes CR     h8     ] (  D4 >  G  6            g  passes
		2 g  exp		2 g  env			2 g  opts			2 g  exp			2 g  env			2  g  filenamef  system/base/compile.scm


					
		
		
		!
		*		2	 
		2	  g  nameg  decompile-fold CRv       hP     - /   0   3 #  #  #  #  45 6        g  x
		N g  env		N g  from			N g  to			N g  opts			N  g  filenamef  system/base/compile.scm

	$		.		7		<		N	 		N
g  envSg  fromS	g  toS	g  optsS	   g  nameg  	decompile C)RC       g  m
		,  g  filenamef  system/base/compile.scm		
	(
	3
	F
c	O
)	l
 
 
 
 
r 
 
h 
# 
'D 
(}
)

+f
 	+h
   C6 